@@ -220,7 +220,7 @@ def untokenize(tokens):
 
 @app.task
 def frog(doc, output='raw'):
-    """Wrapper around the Frog lemmatizer/POS tagger.
+    """Wrapper around the Frog lemmatizer/POS tagger/NER/dependency parser.
 
     Expects Frog to be running in server mode at localhost:9887. It is *not*
     started for you.
@@ -230,7 +230,7 @@ def frog(doc, output='raw'):
 
     The following line starts Frog in the correct way:
 
-    frog --skip=pm -S 9887
+    frog -S 9887
 
     Parameters
     ----------
@@ -394,3 +394,24 @@ def corenlp_lemmatize(doc, output='raw'):
         raise ValueError("Unknown output format %r" % output)
 
     return pipe(doc, fetch, parse, transf)
+
+
+@app.task
+def semafor(saf):
+    """Wrapper around the Semafor semantic parser.
+
+    Expects semafor running in server mode listening to
+    SEMAFOR_HOST:SEMAFOR_PORT (defaults to localhost:9888).
+    It also expects CORENLP_HOME to point to the CoreNLP installation dir.
+
+    Input is expected to be a 'SAF' dictionary with trees and tokens.
+    Output is a SAF dictionary with a frames attribute added.
+
+    References
+    ----------
+    `Semafor github page <https://github.com/sammthomson/semafor>'_
+    `CoreNLP home page <http://nlp.stanford.edu/software/corenlp.shtml>'_
+    """
+    from ._semafor import add_frames
+    add_frames(saf)
+    return saf
