@@ -47,13 +47,23 @@ def _get_task(taskname):
 
 @app.route('/run/<taskname>', methods=['POST'])
 def run_task(taskname):
-    # Wants Content-type: text/plain
+    """Run named task on a document fed as POST data.
+
+    The POST data should have Content-type text/plain.
+    """
     task = _get_task(taskname)
     data = request.data
-    if not isinstance(data, basestring):
-        raise TypeError("data must be string, got %r;"
-                        " Content-type must be text/plain" % type(data))
-    return task.delay(request.data).id
+
+    content_type = request.headers['Content-Type']
+    if content_type == 'text/plain':
+        return task.delay(request.data).id + "\n"
+
+    elif content_type == 'application/json':
+        data = request.json['data']
+        kwargs = request.json.get('arguments', {})
+        return task.delay(data, **kwargs).id + "\n"
+
+    abort(404)  # XXX this is not the right error code
 
 
 @app.route("/run_es/<taskname>/<index>/<type>/<id>/<field>")
@@ -70,12 +80,12 @@ def run_task_on_es(taskname, index, type, id, field):
     task = _get_task(taskname)
     return chain(task.s(es_document(index, type, id, field))
                  | store_single.s(taskname, index, type, id)
-                 ).delay().id
+                 ).delay().id + "\n"
 
 
 @app.route('/result/<jobid>')
 def result(jobid):
-    return json.dumps(celery.result.AsyncResult(jobid).get())
+    return json.dumps(celery.result.AsyncResult(jobid).get()) + "\n"
 
 
 @app.route('/tasks')
